// PROGRESS BARS
// =============
    
   // Danger (red)
   .progress-danger .bar,
   .progress-danger .step-full {
#gradient > .vertical(#ee5f5b, #c43c35);
   }
   .progress-danger.progress-striped .bar {
#gradient > .striped(#ee5f5b);
   }

   // Success (green)
   .progress-success .bar,
   .progress-success .step-full {
#gradient > .vertical(@green, darken(@green,10%));
   }
   .progress-success.progress-striped .bar {
#gradient > .striped(#62c462);
   }

   // Info (teal)
   .progress-info .bar,
   .progress-info .step-full {
#gradient > .vertical(lighten(@infoText,10%), @infoText);
   }
   .progress-info.progress-striped .bar {
#gradient > .striped(#5bc0de);
   }

   // STEP PROGRESS
   // -------------

   .progress-step .step-full, .progress-step .step-empty {
   height: 30px;
   width: 30px;
   background-color: @blue;
   -webkit-border-radius: 15px;
   -moz-border-radius: 15px;
   border-radius: 15px;
   position: absolute;
   left: 0%;
   margin-top: -6px;
   margin-left: -14px;
   font-size: 12pt;
   color: white;
   text-shadow: 0px 0px 3px #222;
   text-align: center;
   line-height: 28px;
   font-weight: bold;
   }
   .progress-step-square {
   .step-full, 
   .step-empty {
   .border-radius(2px);
   }
   }
   .progress-step .step-empty {
#gradient > .vertical(#f5f5f5, #f9f9f9);
   .box-shadow(inset 0 1px 2px rgba(0,0,0,.1));
   }
   .progress.progress-step {
   margin: 14px 17px 18px 14px;
   position: relative;
   overflow: visible;
   }

   // PROGRESS BARS

   // Bar of progress
   .progress .bar {
   width: 0%;
   height: 18px;
   color: @white;
   font-size: 12px;
   text-align: center;
   text-shadow: 0 -1px 0 rgba(0,0,0,.25);

   .box-shadow(inset 0 -1px 0 rgba(0,0,0,.15));
   .box-sizing(border-box);
   .transition(width .6s ease);
   }
   .progress .bar,
   .progress .step-full {
#gradient > .vertical(@blue, darken(@blue,10%));
   }
