// GLYPHICON OVERRIDE
// ==================  

   [class^="icon-"],
   [class*=" icon-"],
   [class^="icomoon-"],
   [class*=" icomoon-"] {
    display: inline-block;
    width: auto;
    height: auto;
    background-image: none;
    background-position: 0;
    background-repeat: no-repeat;
    line-height:normal;
   }
   .icon-white {
    background-image: none;
   }

   @import "fontawesome/less/font-awesome.less"; 	// Using awesomefont instead of an image sprite.
