// BEGIN THEME
// -----------

@import "Kickstrap/themes/spacelab/variables.less";
@import "Kickstrap/themes/spacelab/bootswatch.less";
// Replace the path with any .less file in the 'themes' folder.

// Tweak your current theme here, or comment-out the predefined theme from settings
// and start fresh below.

.container.demo {
  padding-top: 100px;
  img {
    display: block;
    margin: 0px auto;
  }
  h3, p { text-align: center; }
}
